# Credits

## Development Lead

- TIA Centre led by Nasir Rajpoot <tia@dcs.warwick.ac.uk>
- Shan E Ahmed Raza \<@shaneahmed>
- John Pocock \<@John-P>
- Simon Graham \<@simongraham>
- Dang Vu \<@vqdang>
- Mostafa Jahanifar \<@mostafajahanifar>
- David Epstein \<@DavidBAEpstein>
- Mark Eastwood \<@measty>
- Srijay Deshpande \<@Srijay-lab>
- Ruqayya Awan \<@ruqayya>
- Adam Shephard \<@adamshephard>
- George Hadjigeorgiou \<@ghadjigeorghiou>
- Wenqi Lu \<@wenqi006>
- Saad Bashir \<@rajasaad>

## Contributors

- Rob Jewsbury \<@R-J96>
- Mohsin Bilal \<@mbhahsmi>
- Fayyaz Minhas \<@foxtrotmike>
